@@ -32,6 +32,7 @@
 
 #ifdef N900
 #include <libosso.h>
+#include <clutter/x11/clutter-x11.h>
 #endif
 
 
@@ -106,6 +107,7 @@ static void add_search_paths(ClutterScript* script) {
 }
 
 #ifdef N900
+
 static gboolean pause_display_blanking(gpointer user_data) {
 	osso_context_t* osso_context;
 	
@@ -115,6 +117,41 @@ static gboolean pause_display_blanking(gpointer user_data) {
 	
 	return TRUE;
 }
+
+static gint rpc_callback(const gchar* interface, const gchar* method, GArray* arguments, gpointer user_data, osso_rpc_t* retval) {
+	gint return_value = DBUS_TYPE_INVALID;
+	ClutterStage* stage;
+	Display* display;
+	Window window;
+	XEvent event;
+
+	stage = CLUTTER_STAGE(user_data);
+	
+	if (!strcmp(interface, "org.umsic.jammo") && !strcmp(method, "top_application")) {
+		display = clutter_x11_get_default_display();
+		window = clutter_x11_get_stage_window(stage);
+
+		/* Fremantle window manager does not obey XRaiseWindow...
+		XRaiseWindow(display, window);
+		... but reacts on _NET_ACTIVE_WINDOW messages (based on qt for maemo code). */
+		event.xclient.type = ClientMessage;
+		event.xclient.message_type = XInternAtom(display, "_NET_ACTIVE_WINDOW", False);
+		event.xclient.display = display;
+		event.xclient.window = window;
+		event.xclient.format = 32;
+		event.xclient.data.l[0] = 1;
+		event.xclient.data.l[1] = clutter_x11_get_current_event_time();
+		event.xclient.data.l[2] = None;
+		event.xclient.data.l[3] = 0;
+		event.xclient.data.l[4] = 0;
+		XSendEvent(display, clutter_x11_get_root_window(), False, SubstructureNotifyMask | SubstructureRedirectMask, &event);
+
+		return_value = OSSO_OK;
+	}
+	
+	return return_value;
+}
+
 #endif
 
 /* Be sure there are needed place to save compositions and singings.
@@ -140,6 +177,7 @@ int main(int argc, char** argv) {
 	osso_context_t* osso_context;
 #endif
 
+	GType type;
 	TangleStylesheet* stylesheet;
 	gchar* filename;
 	ClutterActor* stage;
@@ -153,9 +191,9 @@ int main(int argc, char** argv) {
 	srand (time (NULL)); //We will use rand()
 
 #ifdef N900
-	osso_context = osso_initialize("org.maemo.jammo", "git", 0, NULL);
+	osso_context = osso_initialize("org.umsic.jammo", VERSION, 0, NULL);
 	g_assert(osso_context != NULL);
-	
+
 	osso_display_state_on(osso_context);
 	osso_display_blanking_pause(osso_context);
 	
@@ -165,7 +203,8 @@ int main(int argc, char** argv) {
 	create_directories();
 
 	/* TODO: Temporary: make sure Mentor classes exists. */
-	printf("%p %p\n", JAMMO_TYPE_MENTOR, JAMMO_TYPE_MENTOR_ACTION);
+	type = JAMMO_TYPE_MENTOR;
+	type = JAMMO_TYPE_MENTOR_ACTION;
 
 	if ((stylesheet = get_jammo_stylesheet())) {
 		tangle_stylesheet_set_default(stylesheet);
@@ -204,6 +243,8 @@ int main(int argc, char** argv) {
 	clutter_stage_set_key_focus(CLUTTER_STAGE(stage), NULL);
 
 #ifdef N900
+	g_assert(osso_rpc_set_default_cb_f(osso_context, rpc_callback, stage) == OSSO_OK);
+	
 	clutter_stage_set_fullscreen(CLUTTER_STAGE(stage), TRUE);
 #else
 	clutter_actor_set_size(stage, 800, 480);
